# Welcome to qtstrap's documentation

qtstrap is a framework that helps you skip over the boring and tedious parts of developing applications with PySide2/PyQt. 

# Features

- `qtstrap` command line tool to bootstrap new projects
- crossplatform makefile with useful development commands
- preconfigured pyinstaller spec file
- preconfigured InnoSetup setup compiler script
- custom Qt widgets with useful behaviors
- Pythonic layout system using ContextLayouts
- Some other stuff I haven't remembered yet

# Roadmap

- Use QtPy to become PySide2/PyQt agnostic
- Write documentation for ContextLayouts
- Find a way to for BaseApplication to pull app info from project.ini
- Create a sane menu bar constructor
- Create an application auto-updater
- Create an application crash reporter
- Set up CI/CD
- Add 'Qt principles' section